==> invoice-client-4.1.28-20220105.084715-8-sources.jar: com/xforceplus/seller/invoice/client/model/MsSysRedNoByInvoiceDto.java <==
package com.xforceplus.seller.invoice.client.model;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.annotations.ApiModel;
import lombok.Data;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

import static com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL;

/**
 * null
 */
@ApiModel(description = "null")
@JsonIgnoreProperties(ignoreUnknown = true)
@JsonInclude(NON_NULL)
@Data
public class MsSysRedNoByInvoiceDto {

  private Long id = null;

  private Long billId = null;

  private String billNo = null;

  private String invoiceCode = null;

  private String invoiceNo = null;

  private BigDecimal amountWithTax = null;

  private BigDecimal amountWithoutTax = null;

  private BigDecimal taxAmount = null;

  private BigDecimal deduction = null;

  private String sellerTaxNo = null;

  private String sellerName = null;

  private String purchaserTaxNo = null;

  private String purchaserName = null;

  private String proposerName = null;

  private String proposerTel = null;

  private Integer applyType = null;

  private String originInvoiceType = null;

  private String invoiceType = null;

  private String paperDrawDate = null;

  private String applyTaxNo = null;

  private Integer saleListFileFlag;

  private String applyRemark = null;

  private Integer applyStatus = null;

  private Integer applyingStatus = null;

  private String sellerNumber = null;

  private String createTime = null;

  private String sellerNo = null;

  private String purchaserNo = null;

  private String requestBillNo = null;

  private Integer syncStatus;

  private String redStatus;

  private String machineCode;

  private String syncMessage;

  private Integer syncCode;

  private String syncSerialNo;

  private String syncStatusMsg;

  private Integer deliveryStatus;

  private String deliveryRemark;

  private String deliveryFailedCode;

  private String salesbillType;

  @JsonProperty("details")
  private List<MsSysRedNoDetailDto> details = new ArrayList<MsSysRedNoDetailDto>();

}

==> invoice-client-4.1.42-20221026.091035-14-sources.jar: com/xforceplus/seller/invoice/client/model/MsSysRedNoByInvoiceDto.java <==
package com.xforceplus.seller.invoice.client.model;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.annotations.ApiModel;
import lombok.Data;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

import static com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL;

/**
 * null
 */
@ApiModel(description = "null")
@JsonIgnoreProperties(ignoreUnknown = true)
@JsonInclude(NON_NULL)
@Data
public class MsSysRedNoByInvoiceDto {

  private Long id = null;

  private Long billId = null;

  private String billNo = null;

  private String invoiceCode = null;

  private String invoiceNo = null;

  private BigDecimal amountWithTax = null;

  private BigDecimal amountWithoutTax = null;

  private BigDecimal taxAmount = null;

  private BigDecimal deduction = null;

  private String sellerTaxNo = null;

  private String sellerName = null;

  private String purchaserTaxNo = null;

  private String purchaserName = null;

  private String proposerName = null;

  private String proposerTel = null;

  private Integer applyType = null;

  private String originInvoiceType = null;

  private String invoiceType = null;

  private String paperDrawDate = null;

  private String applyTaxNo = null;

  private Integer saleListFileFlag;

  private String applyRemark = null;

  private Integer applyStatus = null;

  private Integer applyingStatus = null;

  private String sellerNumber = null;

  private String createTime = null;

  private String sellerNo = null;

  private String purchaserNo = null;

  private String requestBillNo = null;

  private Integer syncStatus;

  private String redStatus;

  private String machineCode;

  private String syncMessage;

  private Integer syncCode;

  private String syncSerialNo;

  private String syncStatusMsg;

  private Integer deliveryStatus;

  private String deliveryRemark;

  private String deliveryFailedCode;

  private String salesbillType;

  private Integer specialInvoiceFlag;

  private String specialInvoiceApplyReason;

  private String applyDate;

  @JsonProperty("details")
  private List<MsSysRedNoDetailDto> details = new ArrayList<MsSysRedNoDetailDto>();

}
